@@ -11,6 +11,7 @@ XRAY_RESOURCE = Resource(
 VALID_EXTENSIONS: SequenceOfStrings = [
     ".dcm",
     ".dicom",
+    ".jpeg",
     ".jpg",
     ".png",
 ]
@@ -19,6 +20,7 @@ VALID_EXTENSIONS: SequenceOfStrings = [
 VALID_MIME_TYPES: SequenceOfStrings = [
     "application/dcm",
     "application/dicom",
+    "image/jpeg",
     "image/jpg",
     "image/png",
 ]
