@@ -1,14 +1,14 @@
+from datetime import date
 from pydantic import BaseModel, Field
 from typing import Annotated, List
 from uuid import UUID
-from maleo.enums.identity import OptionalGender
-from maleo.enums.medical import OptionalService as OptionalMedicalService
+from maleo.enums.identity import Gender
+from maleo.enums.medical import Service as MedicalService
 from maleo.enums.status import DataStatus as DataStatusEnum
 from maleo.schemas.mixins.identity import DataIdentifier
 from maleo.schemas.mixins.status import DataStatus
 from maleo.schemas.mixins.timestamp import DataTimestamp
 from maleo.types.any import ListOfAny
-from maleo.types.datetime import OptionalDate
 from maleo.types.string import OptionalString
 from maleo.types.uuid import OptionalUUID
 from .enums.inference import InferenceType
@@ -24,20 +24,16 @@ class RecordCoreDTO(
     ] = None
     user_id: Annotated[UUID, Field(..., description="User ID")]
     medical_service: Annotated[
-        OptionalMedicalService, Field(None, description="Medical service")
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
+    gender: Annotated[Gender, Field(..., description="Gender")]
+    finding: Annotated[str, Field(..., description="Finding")]
+    impression: Annotated[str, Field(..., description="Impression")]
+    recommendation: Annotated[
+        OptionalString, Field(None, description="Recommendation")
     ] = None
-    name: Annotated[OptionalString, Field(None, description="Name", max_length=200)] = (
-        None
-    )
-    gender: Annotated[OptionalGender, Field(None, description="Gender")] = None
-    date_of_birth: Annotated[OptionalDate, Field(None, description="Date of Birth")] = (
-        None
-    )
-    description: Annotated[OptionalString, Field(None, description="Description")] = (
-        None
-    )
-    impression: Annotated[OptionalString, Field(None, description="Impression")] = None
-    diagnosis: Annotated[str, Field(..., description="Diagnosis")]
     filename: Annotated[str, Field(..., description="File's name")]
 
 
@@ -54,6 +50,12 @@ class InferenceCoreDTO(
         OptionalUUID, Field(None, description="Organization ID")
     ] = None
     user_id: Annotated[UUID, Field(..., description="User ID")]
+    medical_service: Annotated[
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
+    gender: Annotated[Gender, Field(..., description="Gender")]
     type: Annotated[InferenceType, Field(..., description="Inference's type")]
     duration: Annotated[float, Field(0.0, description="Inference's duration")] = 0.0
     output: Annotated[ListOfAny, Field(..., description="Inference's output")]
