@@ -1,18 +1,18 @@
+from datetime import date
 from pydantic import BaseModel, Field
 from typing import (
     Annotated,
     Any,
     Generic,
     Literal,
-    Optional,
     Self,
-    TypeVar,
     Union,
     overload,
 )
 from uuid import UUID, uuid4
+from maleo.enums.identity import Gender
 from maleo.enums.medical import (
-    OptionalService as OptionalMedicalService,
+    Service as MedicalService,
     OptionalListOfServices as OptionalListOfMedicalServices,
 )
 from maleo.enums.status import (
@@ -34,7 +34,6 @@ from maleo.schemas.parameter import (
 from maleo.types.any import ListOfAny
 from maleo.types.dict import StringToAnyDict
 from maleo.types.integer import OptionalListOfIntegers
-from maleo.types.misc import StringOrStringEnum
 from maleo.types.uuid import OptionalListOfUUIDs, OptionalUUID
 from ...mixins import MedicalServices
 from ..enums.inference import (
@@ -47,38 +46,6 @@ from ..mixins.inference import InferenceTypes
 from ..types.inference import IdentifierValueType
 
 
-class BoundingBox(BaseModel):
-    x_min: Annotated[float, Field(0.0, description="X Min", ge=0.0)]
-    y_min: Annotated[float, Field(0.0, description="Y Min", ge=0.0)]
-    x_max: Annotated[float, Field(0.0, description="X Max", ge=0.0)]
-    y_max: Annotated[float, Field(0.0, description="Y Max", ge=0.0)]
-
-
-OptionalBoundingBox = Optional[BoundingBox]
-OptionalBoundingBoxT = TypeVar("OptionalBoundingBoxT", bound=OptionalBoundingBox)
-
-
-class Finding(BaseModel, Generic[OptionalBoundingBoxT]):
-    id: Annotated[int, Field(..., description="Finding's ID")]
-    name: Annotated[StringOrStringEnum, Field(..., description="Finding's Name")]
-    confidence: Annotated[float, Field(..., description="Confidence", ge=0.0, le=1.0)]
-    box: Annotated[OptionalBoundingBoxT, Field(..., description="Bounding Box")]
-
-
-class FindingWithoutBox(Finding[None]):
-    pass
-
-
-class FindingWithBox(Finding[BoundingBox]):
-    pass
-
-
-AnyFinding = Union[FindingWithoutBox, FindingWithBox]
-AnyFindingT = TypeVar("AnyFindingT", bound=AnyFinding)
-OptionalAnyFinding = Optional[AnyFinding]
-OptionalAnyFindingT = TypeVar("OptionalAnyFindingT", bound=OptionalAnyFinding)
-
-
 class GenericPredictParameter(BaseModel, Generic[InferenceTypeT]):
     inference_id: Annotated[UUID, Field(uuid4(), description="Inference ID")] = uuid4()
     organization_id: Annotated[
@@ -86,8 +53,11 @@ class GenericPredictParameter(BaseModel, Generic[InferenceTypeT]):
     ] = None
     user_id: Annotated[UUID, Field(..., description="User ID")]
     medical_service: Annotated[
-        OptionalMedicalService, Field(None, description="Medical service")
-    ] = None
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
+    gender: Annotated[Gender, Field(..., description="Gender")]
     inference_type: Annotated[
         InferenceTypeT, Field(..., description="Inference's type")
     ]
@@ -130,8 +100,11 @@ class GenericCreateParameter(BaseModel, Generic[InferenceTypeT]):
     ] = None
     user_id: Annotated[UUID, Field(..., description="User ID")]
     medical_service: Annotated[
-        OptionalMedicalService, Field(None, description="Medical service")
-    ] = None
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
+    gender: Annotated[Gender, Field(..., description="Gender")]
     type: Annotated[InferenceTypeT, Field(..., description="Inference's type")]
     filename: Annotated[str, Field(..., description="File name")]
     duration: Annotated[float, Field(0.0, description="Inference's duration")] = 0.0
@@ -152,6 +125,9 @@ class GenericCreateParameter(BaseModel, Generic[InferenceTypeT]):
             organization_id=parameters.organization_id,
             user_id=parameters.user_id,
             medical_service=parameters.medical_service,
+            name=parameters.name,
+            date_of_birth=parameters.date_of_birth,
+            gender=parameters.gender,
             type=parameters.inference_type,
             duration=duration,
             filename=parameters.filename,
