@@ -1,3 +1,4 @@
+from datetime import date
 from pydantic import BaseModel, Field
 from typing import (
     Annotated,
@@ -8,8 +9,9 @@ from typing import (
     overload,
 )
 from uuid import UUID, uuid4
-from maleo.enums.identity import OptionalGender
+from maleo.enums.identity import Gender, OptionalGender
 from maleo.enums.medical import (
+    Service as MedicalService,
     OptionalService as OptionalMedicalService,
     OptionalListOfServices as OptionalListOfMedicalServices,
 )
@@ -22,7 +24,6 @@ from maleo.schemas.mixins.identity import (
     IdentifierTypeValue,
     Ids,
     UUIDs,
-    Name,
     UUIDOrganizationIds,
     UUIDUserIds,
 )
@@ -50,20 +51,16 @@ class CreateParameter(BaseModel):
     ] = None
     user_id: Annotated[UUID, Field(..., description="User ID")]
     medical_service: Annotated[
-        OptionalMedicalService, Field(None, description="Medical service")
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
+    gender: Annotated[Gender, Field(..., description="Gender")]
+    finding: Annotated[str, Field(..., description="Finding")]
+    impression: Annotated[str, Field(..., description="Impression")]
+    recommendation: Annotated[
+        OptionalString, Field(None, description="Recommendation")
     ] = None
-    name: Annotated[OptionalString, Field(None, description="Name", max_length=200)] = (
-        None
-    )
-    gender: Annotated[OptionalGender, Field(None, description="Gender")] = None
-    date_of_birth: Annotated[OptionalDate, Field(None, description="Date of Birth")] = (
-        None
-    )
-    description: Annotated[OptionalString, Field(None, description="Description")] = (
-        None
-    )
-    impression: Annotated[OptionalString, Field(None, description="Impression")] = None
-    diagnosis: Annotated[str, Field(..., description="Diagnosis")]
     content_type: Annotated[str, Field(..., description="Content type")]
     image: Annotated[bytes, Field(..., description="Image data")]
     filename: Annotated[str, Field(..., description="File name")]
@@ -82,20 +79,16 @@ class InsertData(BaseModel):
     ] = None
     user_id: Annotated[UUID, Field(..., description="User ID")]
     medical_service: Annotated[
-        OptionalMedicalService, Field(None, description="Medical service")
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
+    gender: Annotated[Gender, Field(..., description="Gender")]
+    finding: Annotated[str, Field(..., description="Finding")]
+    impression: Annotated[str, Field(..., description="Impression")]
+    recommendation: Annotated[
+        OptionalString, Field(None, description="Recommendation")
     ] = None
-    name: Annotated[OptionalString, Field(None, description="Name", max_length=200)] = (
-        None
-    )
-    gender: Annotated[OptionalGender, Field(None, description="Gender")] = None
-    date_of_birth: Annotated[OptionalDate, Field(None, description="Date of Birth")] = (
-        None
-    )
-    description: Annotated[OptionalString, Field(None, description="Description")] = (
-        None
-    )
-    impression: Annotated[OptionalString, Field(None, description="Impression")] = None
-    diagnosis: Annotated[str, Field(..., description="Diagnosis")]
     filename: Annotated[str, Field(..., description="File name")]
 
     @classmethod
@@ -104,12 +97,13 @@ class InsertData(BaseModel):
             uuid=parameters.record_id,
             organization_id=parameters.organization_id,
             user_id=parameters.user_id,
+            medical_service=parameters.medical_service,
             name=parameters.name,
-            gender=parameters.gender,
             date_of_birth=parameters.date_of_birth,
-            description=parameters.description,
+            gender=parameters.gender,
+            finding=parameters.finding,
             impression=parameters.impression,
-            diagnosis=parameters.diagnosis,
+            recommendation=parameters.recommendation,
             filename=parameters.filename,
         )
 
@@ -186,31 +180,36 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         )
 
 
-class BaseUpdateData(
-    Name[OptionalString],
-):
+class FullUpdateData(BaseModel):
+    medical_service: Annotated[
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
+    gender: Annotated[Gender, Field(..., description="Gender")]
+    finding: Annotated[str, Field(..., description="Finding")]
+    impression: Annotated[str, Field(..., description="Impression")]
+    recommendation: Annotated[
+        OptionalString, Field(None, description="Recommendation")
+    ] = None
+
+
+class PartialUpdateData(BaseModel):
     medical_service: Annotated[
         OptionalMedicalService, Field(None, description="Medical service")
     ] = None
     name: Annotated[OptionalString, Field(None, description="Name", max_length=200)] = (
         None
     )
-    gender: Annotated[OptionalGender, Field(None, description="Gender")] = None
     date_of_birth: Annotated[OptionalDate, Field(None, description="Date of Birth")] = (
         None
     )
-    description: Annotated[OptionalString, Field(None, description="Description")] = (
-        None
-    )
+    gender: Annotated[OptionalGender, Field(None, description="Gender")] = None
+    finding: Annotated[OptionalString, Field(None, description="Finding")] = None
     impression: Annotated[OptionalString, Field(None, description="Impression")] = None
-
-
-class FullUpdateData(BaseUpdateData):
-    diagnosis: Annotated[str, Field(..., description="Diagnosis")]
-
-
-class PartialUpdateData(BaseUpdateData):
-    diagnosis: Annotated[OptionalString, Field(None, description="Diagnosis")] = None
+    recommendation: Annotated[
+        OptionalString, Field(None, description="Recommendation")
+    ] = None
 
 
 UpdateDataT = TypeVar("UpdateDataT", FullUpdateData, PartialUpdateData)
